@@ -30,7 +30,7 @@ from django_celery_extensions.task import get_django_command_task
 
 from security.config import settings
 from security.decorators import log_with_data
-from security.enums import CeleryTaskInvocationLogState, CeleryTaskRunLogState
+from security.enums import CeleryTaskInvocationLogState, CeleryTaskRunLogState, LoggerName
 from security.backends.sql.models import CeleryTaskRunLog as SQLCeleryTaskRunLog
 from security.backends.sql.models import CeleryTaskInvocationLog as SQLCeleryTaskInvocationLog
 from security.backends.elasticsearch.models import CeleryTaskRunLog as ElasticsearchCeleryTaskRunLog
@@ -41,17 +41,19 @@ from security.backends.signals import (
     celery_task_invocation_ignored, celery_task_invocation_timeout, celery_task_run_started, celery_task_run_failed,
     celery_task_run_retried, celery_task_run_succeeded, celery_task_run_output_updated
 )
-from security.tests import capture_security_logs
+from security.backends.testing import capture_security_logs
+from security.backends.reader import get_logs_related_with_object
 
 from apps.test_security.tasks import error_task, retry_task, sum_task, unique_task, ignored_after_success_task
 
 from .base import BaseTestCaseMixin, TRUNCATION_CHAR, test_call_command
 
 
-@override_settings(SECURITY_BACKENDS={})
+@override_settings(SECURITY_BACKEND_WRITERS={})
 class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
 
     @data_consumer('create_user')
+    @override_settings(SECURITY_BACKEND_READER='testing')
     def test_sum_celery_task_should_be_logged(self, user):
         expected_invocation_started_data = {
             'name': 'sum_task',
@@ -105,6 +107,10 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             assert_equal(logged_data.celery_task_run_started[0].data, expected_run_started_data)
             assert_equal(logged_data.celery_task_run_succeeded[0].data, expected_run_succeeded_data)
             assert_equal(logged_data.celery_task_invocation[0].related_objects, {user})
+            assert_equal(
+                get_logs_related_with_object(LoggerName.CELERY_TASK_INVOCATION, user),
+                [logged_data.celery_task_invocation[0]]
+            )
 
     def test_error_celery_task_should_be_logged(self):
         expected_invocation_started_data = {
@@ -266,7 +272,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                 ContentType.objects.get_for_model(User)
             )
 
-    @override_settings(SECURITY_BACKENDS={'sql'})
+    @override_settings(SECURITY_BACKEND_WRITERS={'sql'})
     @data_consumer('create_user')
     def test_sum_celery_task_should_be_logged_in_sql_backend(self, user):
         with log_with_data(related_objects=[user]):
@@ -303,7 +309,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                 retries=0
             )
 
-    @override_settings(SECURITY_BACKENDS={'elasticsearch'})
+    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'})
     @data_consumer('create_user')
     def test_sum_celery_task_should_be_logged_in_elasticsearch_backend(self, user):
         with log_with_data(related_objects=[user]):
@@ -351,7 +357,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     retries=0
                 )
 
-    @override_settings(SECURITY_BACKENDS={'logging'})
+    @override_settings(SECURITY_BACKEND_WRITERS={'logging'})
     def test_sum_celery_task_should_be_logged_in_logging_backend(self):
         with capture_security_logs() as logged_data:
             with self.assertLogs('security.celery', level='INFO') as cm:
@@ -373,7 +379,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     ]
                 )
 
-    @override_settings(SECURITY_BACKENDS={'sql'})
+    @override_settings(SECURITY_BACKEND_WRITERS={'sql'})
     def test_error_celery_task_should_be_logged_in_sql_backend(self):
         error_task.apply()
         assert_equal(SQLCeleryTaskInvocationLog.objects.count(), 1)
@@ -407,7 +413,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
         )
         assert_is_not_none(sql_celery_task_run_log.error_message)
 
-    @override_settings(SECURITY_BACKENDS={'elasticsearch'})
+    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'})
     def test_error_celery_task_should_be_logged_in_elasticsearch_backend(self):
         with capture_security_logs() as logged_data:
             error_task.apply()
@@ -446,7 +452,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             )
             assert_is_not_none(elasticsearch_celery_task_run_log.error_message)
 
-    @override_settings(SECURITY_BACKENDS={'logging'})
+    @override_settings(SECURITY_BACKEND_WRITERS={'logging'})
     def test_error_celery_task_should_be_logged_in_logging_backend(self):
         with capture_security_logs() as logged_data:
             with self.assertLogs('security.celery', level='INFO') as cm:
@@ -468,7 +474,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                     ]
                 )
 
-    @override_settings(SECURITY_BACKENDS={'sql'})
+    @override_settings(SECURITY_BACKEND_WRITERS={'sql'})
     def test_retry_celery_task_should_be_logged_in_sql_backend(self):
         with capture_security_logs() as logged_data:
             retry_task.apply()
@@ -518,7 +524,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             )
             assert_equal(sql_celery_task_invocation_log.last_run.id, sql_celery_task_run_log.id)
 
-    @override_settings(SECURITY_BACKENDS={'elasticsearch'})
+    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'})
     def test_retry_celery_task_should_be_logged_in_elasticsearch_backend(self):
         with capture_security_logs() as logged_data:
             retry_task.apply()
@@ -577,7 +583,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             ElasticsearchCeleryTaskRunLog._index.refresh()
             assert_equal(elasticsearch_celery_task_invocation_log.last_run.id, elasticsearch_celery_task_run_log.id)
 
-    @override_settings(SECURITY_BACKENDS={'logging'})
+    @override_settings(SECURITY_BACKEND_WRITERS={'logging'})
     def test_retry_celery_task_should_be_logged_in_logging_backend(self):
         with capture_security_logs() as logged_data:
             with self.assertLogs('security.celery', level='INFO') as cm:
@@ -607,7 +613,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                 ]
                 assert_equal(cm.output, expected_output)
 
-    @override_settings(SECURITY_BACKENDS={'sql'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
+    @override_settings(SECURITY_BACKEND_WRITERS={'sql'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
     def test_set_celery_task_log_state_should_set_task_to_failed_with_sql_backend(self):
         with mock.patch.object(unique_task, '_get_unique_task_id') as apply_method:
             unique_task_id = uuid4()
@@ -615,18 +621,18 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             unique_task.apply_async()
 
             sql_celery_task_invocation_log = SQLCeleryTaskInvocationLog.objects.get()
-            test_call_command('sql_set_celery_task_log_state')
+            test_call_command('set_celery_task_log_state')
             sql_celery_task_invocation_log.refresh_from_db()
             assert_equal(
                 sql_celery_task_invocation_log.state, CeleryTaskInvocationLogState.TRIGGERED
             )
 
             with freeze_time(now() + timedelta(seconds=30)):
-                test_call_command('sql_set_celery_task_log_state')
+                test_call_command('set_celery_task_log_state')
                 sql_celery_task_invocation_log.refresh_from_db()
                 assert_equal(sql_celery_task_invocation_log.state, CeleryTaskInvocationLogState.EXPIRED)
 
-    @override_settings(SECURITY_BACKENDS={'elasticsearch'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
+    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
     def test_set_celery_task_log_state_should_set_task_to_failed_with_elasticsearch_backend(self):
         with capture_security_logs() as logged_data:
             with mock.patch.object(unique_task, '_get_unique_task_id') as apply_method:
@@ -635,7 +641,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                 unique_task.apply_async()
                 ElasticsearchCeleryTaskInvocationLog._index.refresh()
 
-                test_call_command('elasticsearch_set_celery_task_log_state')
+                test_call_command('set_celery_task_log_state')
                 assert_equal(
                     ElasticsearchCeleryTaskInvocationLog.get(
                         id=logged_data.celery_task_invocation[0].id
@@ -643,7 +649,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                 )
 
                 with freeze_time(now() + timedelta(seconds=30)):
-                    test_call_command('elasticsearch_set_celery_task_log_state')
+                    test_call_command('set_celery_task_log_state')
                     assert_equal(
                         ElasticsearchCeleryTaskInvocationLog.get(
                             id=logged_data.celery_task_invocation[0].id
@@ -651,25 +657,25 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
                         CeleryTaskInvocationLogState.EXPIRED
                     )
 
-    @override_settings(SECURITY_BACKENDS={'sql'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
+    @override_settings(SECURITY_BACKEND_WRITERS={'sql'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
     def test_set_celery_task_log_state_should_set_task_to_succeeded_with_sql_backend(self):
         unique_task.apply_async()
 
         sql_celery_task_invocation_log = SQLCeleryTaskInvocationLog.objects.get()
         change_and_save(sql_celery_task_invocation_log, state=CeleryTaskInvocationLogState.TRIGGERED)
 
-        test_call_command('sql_set_celery_task_log_state')
+        test_call_command('set_celery_task_log_state')
         sql_celery_task_invocation_log.refresh_from_db()
         assert_equal(
             sql_celery_task_invocation_log.state, CeleryTaskInvocationLogState.TRIGGERED
         )
 
         with freeze_time(now() + timedelta(seconds=30)):
-            test_call_command('sql_set_celery_task_log_state')
+            test_call_command('set_celery_task_log_state')
             sql_celery_task_invocation_log.refresh_from_db()
             assert_equal(sql_celery_task_invocation_log.state, CeleryTaskInvocationLogState.SUCCEEDED)
 
-    @override_settings(SECURITY_BACKENDS={'elasticsearch'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
+    @override_settings(SECURITY_BACKEND_WRITERS={'elasticsearch'}, DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
     def test_set_celery_task_log_state_should_set_task_to_succeeded_with_elasticsearch_backend(self):
         with capture_security_logs() as logged_data:
             unique_task.apply_async()
@@ -679,7 +685,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             ElasticsearchCeleryTaskInvocationLog._index.refresh()
             ElasticsearchCeleryTaskRunLog._index.refresh()
 
-            test_call_command('elasticsearch_set_celery_task_log_state')
+            test_call_command('set_celery_task_log_state')
             assert_equal(
                 ElasticsearchCeleryTaskInvocationLog.get(
                     id=logged_data.celery_task_invocation[0].id
@@ -687,7 +693,7 @@ class CeleryLogTestCase(BaseTestCaseMixin, ClientTestCase):
             )
 
             with freeze_time(now() + timedelta(seconds=30)):
-                test_call_command('elasticsearch_set_celery_task_log_state')
+                test_call_command('set_celery_task_log_state')
                 assert_equal(
                     ElasticsearchCeleryTaskInvocationLog.get(
                         id=logged_data.celery_task_invocation[0].id
